@@ -15,11 +15,21 @@ Loads YAML files. Example:
 
     ---
     name: TestApp
-    Controller::Config:
+    Controller::Foo:
         foo: bar
 
 =head1 METHODS
 
+=head2 extensions( )
+
+return an array of valid extensions (C<yml>, C<yaml>).
+
+=cut
+
+sub extensions {
+    return qw( yml yaml );
+}
+
 =head2 load( $file )
 
 Attempts to load C<$file> as a YAML file.
@@ -27,30 +37,17 @@ Attempts to load C<$file> as a YAML file.
 =cut
 
 sub load {
-	my $class    = shift;
-	my $confpath = shift;
+    my $class = shift;
+    my $file  = shift;
 
-	my @files;
-    if( $confpath =~ /\.(.{3,4})$/ ) {
-        return unless $1 =~ /^ya?ml$/;
-        @files = $confpath;
+    eval { require YAML::Syck; };
+    if( $@ ) {
+        require YAML;
+        return YAML::LoadFile( $file );
     }
     else {
-        @files = map { "$confpath.$_" } qw( yml yaml );
-    }
-    
-    for my $file ( @files ) {
-        next unless -f $file;
-
-        eval { require YAML::Syck; };
-        if( $@ ) {
-            require YAML;
-            return YAML::LoadFile( $file );
-        }
-        else {
-            my $content = read_file( $file );
-            return YAML::Syck::Load( $content );
-        }
+        my $content = read_file( $file );
+        return YAML::Syck::Load( $content );
     }
 }
 
@@ -75,6 +72,8 @@ it under the same terms as Perl itself.
 
 =item * L<Catalyst>
 
+=item * <Catalyst::Plugin::ConfigLoader>
+
 =back
 
 =cut
